# Bulk Updating Data in Inventory Table View
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view#introduction)
  * [Table View](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view#table-view)
  * [Inline Editing](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view#inline-editing)
  * [Editable and Non-Editable Fields](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view#editable-and-non-editable-fields)
  * [Keyboard Accessibility](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view#keyboard-accessibility)
  * [Bulk Updating Data Through an Excel File](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view#bulk-updating-data-through-an-excel-file)


_Table View lets you view and edit multiple fact sheets in a spreadsheet-like format—perfect for scanning, comparing, and updating data quickly and efficiently._
